import QtQuick 2.5
import Fly.Components 1.0

FlyNotificationItem {
    id: notificationItem

    property bool paused: _notification && _notification.dataMap["paused"]
    property int position: _notification.dataMap["position"]
    property int duration: _notification.dataMap["duration"]
    property string firstTitle: _notification.dataMap["firstTitle"]
    property string secondTitle: _notification.dataMap["secondTitle"]
    property string cover: _notification.dataMap["cover"]
    //property string iconPath: "file:///home/user/projects/fly-music/app/icons/";
    //property string iconPath: "file:///usr/share/rusbitech/fly-music/icons/";


    description.visible: false
    description.y: height * 0.6
    description.height: height * 0.4

    icon.imagePath: "image://ColorThemeImageProvider/fly-music"
    icon.imageColorEnabled: true
    icon.imageColor: styles.colors.darkred

    function clicked() {
        root.startDetachedProcess("fly-music", ["--raise"]);
        return false; // close notification panel
    }

    Rectangle {
        anchors.fill: parent
        color: styles.colors.black3

        Image {
            id: coverImage
            anchors { left: parent.left; top: parent.top; bottom: parent.bottom; }
            width: parent.height
            source: cover.length === 0 ? ("image://ThemeImageProvider/empty-cover") : notificationItem.cover;
            sourceSize: Qt.size(2*width, 0)
            asynchronous: true
        }

        FlyLabel {
            id: firstTitle
            anchors { leftMargin: 10 * dpiRatio; topMargin: 5* dpiRatio; left: coverImage.right; right: parent.right; top: parent.top }
            height: parent.height / 4
            text: notificationItem.firstTitle
            color: styles.colors.white
        }

        FlyLabel {
            id: secondTitle
            anchors { leftMargin: 10 * dpiRatio; left: coverImage.right; right: parent.right; top: firstTitle.bottom }
            height: parent.height / 4
            text: notificationItem.secondTitle
            color: styles.colors.white
        }

        Item {
            id: positionbar
            anchors {
                margins: 10 * dpiRatio;
                left: coverImage.right;
                right: previousButton.left;
                top: secondTitle.bottom;
                bottom: parent.bottom
            }
            property alias duration: notificationItem.duration
            property alias position: notificationItem.position
            property alias color: highlight.color
            signal seekRequest(int pos)

            Rectangle {
                id: backGround
                anchors { fill: parent }
                color: styles.colors.gray

                Rectangle {
                    id: highlight
                    width: positionbar.duration > 0 ? (parent.width * positionbar.position / positionbar.duration) : 0

                    anchors { left: parent.left; top: parent.top; bottom: parent.bottom }
                    color: styles.colors.white
                }


                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        if(positionbar.duration > 0)
                            positionbar.seekRequest(mouse.x  * positionbar.duration / width);
                    }

                    onMouseXChanged: {
                        if(containsPress && positionbar.duration > 0)
                            positionbar.seekRequest(mouse.x  * positionbar.duration / width);
                    }
                }
            }

            onSeekRequest: _notification.newData("seek=" + pos);
        }

        FlyMenuButton {
            id: previousButton
            anchors { top: secondTitle.bottom; right: playPauseButton.left; bottom: parent.bottom; margins: 10 * dpiRatio }
            width: parent.height / 2 - 20 * dpiRatio
            image.imagePath:  "image://ThemeImageProvider/media-skip-backward"
            onClicked: _notification.newData("previous")
        }

        FlyMenuButton {
            id: playPauseButton
            anchors { top: secondTitle.bottom; right: nextButton.left; bottom: parent.bottom; margins: 10 * dpiRatio }
            width: parent.height / 2 - 20 * dpiRatio
            image.imagePath: (paused ? "image://ThemeImageProvider/media-playback-start" : "image://ThemeImageProvider/media-playback-pause")
            onClicked: _notification.newData("pause")

        }

        FlyMenuButton {
            id: nextButton
            anchors { top: secondTitle.bottom; right: parent.right; bottom: parent.bottom; margins: 10 * dpiRatio }
            width: parent.height / 2 - 20 * dpiRatio
            image.imagePath:  "image://ThemeImageProvider/media-skip-forward"
            onClicked: _notification.newData("next")
        }
    }
}
